@@ -53,7 +53,7 @@ class DatazillaPerfPoster(object):
                 pass
 
             device_name = 'unknown'
-            build_prop = device_manager.pullFile('/system/build.prop')
+            build_prop = self.device.manager.pullFile('/system/build.prop')
             device_prefix = 'ro.product.device='
             for line in build_prop.split('\n'):
                 if line.startswith(device_prefix):
